/*****************************************************************************
 * Copyright 2016-2017 Karolin Stange, Christoph Wick, and Haye Hinrichsen
 *
 * This file is part of JustIntonation.
 *
 * JustIntonation is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * JustIntonation is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with JustIntonation. If not, see http://www.gnu.org/licenses/.
 *****************************************************************************/

#ifndef TUNERKEYDATA_H
#define TUNERKEYDATA_H

#include <QVector>

///////////////////////////////////////////////////////////////////////////////
/// \brief Structure holding the tuner's data of a single key
/// \ingroup tuner
/// \details The tuner keeps track of each pressed key. This structure holds
/// the essential data associated with the pressed key.
///////////////////////////////////////////////////////////////////////////////

struct TunerKeyData
{
    int key;                        // number of the key
    bool pressed;                   // flag indicating a pressed key
    bool newlyPressed;              // flag indicating a newly pressed key
    bool emitted;                   // flag indicating first emission
    double intensity;               // intensity of the keypress
    double memory;                  // flag for psychoacoustic memory
    double sustainDampingFactor;    // sustain damping of the key
    double releaseDampingFactor;    // release damping of the key
    qint64 timeStamp;               // time when the key was pressed
    double pitch;                   // actual pitch
    double previousPitch;           // previously emitted pitch

    TunerKeyData() { clear(); }     ///< Constructor

    /// \brief Function for clearing all fields in the TunerKeyData structure
    void clear()
    {
        key=0;
        pressed = newlyPressed = emitted = false;
        intensity = memory = pitch = previousPitch = 0;
        sustainDampingFactor = 1;
        releaseDampingFactor = 0;
        timeStamp = 0;
    }
};

using KeyData = QVector<TunerKeyData>;

#endif // TUNERKEYDATA_H
