/*****************************************************************************
 * Copyright 2016-2017 Karolin Stange, Christoph Wick, and Haye Hinrichsen
 *
 * This file is part of JustIntonation.
 *
 * JustIntonation is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * JustIntonation is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with JustIntonation. If not, see http://www.gnu.org/licenses/.
 *****************************************************************************/

import QtQuick 2.3

Item {
    anchors.fill: parent
    property alias value: slider.value
    property color rawcolor: "red"
    property color col: backgroundColor
    property double red
    property double green
    property double blue

    TextHeader {
        id: header
        text: qsTr("Please choose a background color")
    }

    Item {
        id: slider
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.leftMargin: parent.width*(landscape ? 0.95 : 0.9)
        anchors.bottomMargin: width
        property real value: (pickerCursor.y/height)
        Rectangle {

             anchors.fill: parent
             border.color: "black"
             gradient: Gradient {
                 GradientStop { position: 1.0;  color: "#FF0000" }
                 GradientStop { position: 0.84; color: "#FFFF00" }
                 GradientStop { position: 0.67; color: "#00FF00" }
                 GradientStop { position: 0.5;  color: "#00FFFF" }
                 GradientStop { position: 0.33; color: "#0000FF" }
                 GradientStop { position: 0.16; color: "#FF00FF" }
                 GradientStop { position: 0.0;  color: "#FF0000" }
             }
        }
        Item {
            id: pickerCursor
            y: slider.height*0.9
            width: parent.width
            Rectangle {
                width: parent.width + 4;
                height: 7
                border.color: "black"; border.width: 1
                color: "transparent"
                Rectangle {
                    anchors.fill: parent; anchors.margins: 2
                    border.color: "white"; border.width: 1
                    color: "transparent"
                }
            }
        }
        MouseArea {
            anchors.fill: parent
            function handleMouse(mouse) {
                if (mouse.buttons & Qt.LeftButton) {
                    console.log(mouse.y)
                    pickerCursor.y = Math.max(0, Math.min(height-8, mouse.y))
                }
            }
            onPositionChanged: handleMouse(mouse)
            onPressed: handleMouse(mouse)
        }
    }

    onValueChanged: {
        if (value < 0.16) { red=1; green=0; blue=value/0.16; }
        else if (value < 0.33) { red=1-(value-0.16)/0.17; green=0; blue=1 }
        else if (value < 0.5) { red=0; green=(value-0.33)/0.17; blue=1 }
        else if (value < 0.67) { red=0; green=1; blue=1-(value-0.5)/0.17 }
        else if (value < 0.85) { red=(value-0.67)/0.18; green=1; blue=0 }
        else { red=1; green=1-(value-0.84)/0.16; blue=0 }
        rawcolor = Qt.rgba(red,green,blue);
    }

    Rectangle {
        id: square
        color: col
        anchors.top: slider.bottom
        anchors.left: slider.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        border.color: "black"
        MouseArea {
            anchors.fill: parent
            onClicked: {
                // Standard color for documentation purposes
                chosenBackgroundColor = "#ffdfce"
                stack.pop()
            }
        }
    }

    Rectangle {
        id: blackbar
        color: "black"
        anchors.right: slider.left
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        width: parent.width*0.01
    }

    Item {
        id: area
        anchors.left: parent.left
        anchors.right: blackbar.left
        anchors.top: header.bottom
        anchors.bottom: parent.bottom

        Rectangle {
            anchors.fill: parent
            color: "white"
        }
        Rectangle {
            width: area.height
            height: area.width
            x: (area.width-area.height)/2
            y: (area.height-area.width)/2
            rotation: -90
            gradient: Gradient {
                GradientStop {
                    position: 0.0; color: "#FFFFFFFF"
                }
                GradientStop {
                    position: 1.0; color: rawcolor
                }
            }
        }
        Rectangle {
            anchors.fill: parent
            gradient: Gradient {
                GradientStop {
                    position: 1.0; color: "#FF000000"
                }
                GradientStop {
                    position: 0.0; color: "#00000000"
                }
            }
        }
        MouseArea {
            anchors.fill: parent
            function handleMouse(mouse) {
                if (mouse.buttons & Qt.LeftButton) {
                    var w = Math.max(0, Math.min(1, mouse.x/width))
                    var i = 1-Math.max(0, Math.min(1, mouse.y/height))
                    col = Qt.rgba(i*(1-w+w*red),i*(1-w+w*green),i*(1-w+w*blue))
                }
            }
            onPositionChanged: handleMouse(mouse)
            onPressed: handleMouse(mouse)
            onReleased: {
                chosenBackgroundColor = col
                stack.pop()
            }
        }
    }
    Component.onCompleted: col=backgroundColor
}
