/*****************************************************************************
 * Copyright 2016-2017 Karolin Stange, Christoph Wick, and Haye Hinrichsen
 *
 * This file is part of JustIntonation.
 *
 * JustIntonation is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * JustIntonation is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with JustIntonation. If not, see http://www.gnu.org/licenses/.
 *****************************************************************************/

//=============================================================================
//                  Class for playing a startup sound
//=============================================================================

#ifndef STARTUPSOUND_H
#define STARTUPSOUND_H

#include <QObject>

#include "system/shared.h"

///////////////////////////////////////////////////////////////////////////////
/// \brief Class for playing a startup sound
/// \ingroup system
/// This module manages to play a short audio file at startup (welcome jingle).
/// \details This module manages to play a short audio file at startup.
/// The file should be stored both in mp3 format (for Apple) and int ogg
/// format (for Linux and Android) as resource files (qrc:/...). The
/// QMediaPlayer forwards the request to a platform-dependent streamer.
/// Since some streamers cannot process resource files directly, the audio
/// file (specified when calling the constructor) is first downloaded and
/// then played.
///////////////////////////////////////////////////////////////////////////////

class StartupSound : public QObject
{
    Q_OBJECT
public:
    StartupSound(const QString& resourcefile);
    bool isEnabled();
    void setVerbosity (int verbosity);

public slots:
    void enable (bool enabled);
    void play ();

private:
    QString mResourceFile;      ///< Resource file object
    int mVerbosity;             ///< Verbosity of qDebug() messages
};

#endif // STARTUPSOUND_H
