#!/bin/bash
# Script for generating a Linux installer
#
# Download: http://download.qt.io/official_releases/qt-installer-framework/
#
echo
echo "========= LINUX INSTALLATION SCRIPT ============"
echo
echo "To see which dynamic libraries are needed just type objdump -p justintonation"
echo "To see the corresponding locations on hdd just type ldd justintonation"

# Update these lines:
FRAMEWORK=$HOME/Software/Qt/Tools/QtInstallerFramework/2.0/bin
SYSDLLPATH=/usr/lib64
QTPATH=$HOME/Software/Qt/5.8/gcc_64
SOURCEPATH=$HOME/Dokumente/Projekte/JI/JustIntonation
BUILDPATH=$HOME/build
RELEASEPATH=$BUILDPATH/build-justintonation-Desktop_Qt_5_8_0_GCC_64bit-Release
QMLDIR=$SOURCEPATH/application/resources/qml
TARGETURL='u81468700@s582786137.online.de:justintonation/download/Resources/Public/Downloads'

##################################################################################

echo
echo "Installer script for Opensuse Linux GCC"

##################################################################################

echo
echo "Build the application"
bash build-linux.sh $QTPATH $SOURCEPATH $RELEASEPATH
echo

##################################################################################


# Create the template of an installer in the build directory
echo "Remove old installer if existent"
rm -r -f $BUILDPATH/installer
echo "Copy installer tree structure to buildpath" $BUILDPATH
cp -r $SOURCEPATH/publish/installer $BUILDPATH

# Copy the release to the data section of the installer
echo "Copy release to installer"
INSTALLERDATA=$BUILDPATH/installer/packages/org.justintonation.app/data
cp -r $RELEASEPATH/application/* $INSTALLERDATA

# Copy the necessary Qt libraries
echo "Copy the necessary Qt libraries"
cp $QTPATH/lib/libQt5Quick* $INSTALLERDATA
cp $QTPATH/lib/libQt5Widgets* $INSTALLERDATA
cp $QTPATH/lib/libQt5Multimedia* $INSTALLERDATA
cp $QTPATH/lib/libQt5Gui* $INSTALLERDATA
cp $QTPATH/lib/libQt5Qm* $INSTALLERDATA
cp $QTPATH/lib/libQt5Network* $INSTALLERDATA
cp $QTPATH/lib/libQt5Core* $INSTALLERDATA

# Copy the necessary non-Qt libraries 
echo "Copy the necessary non-Qt libraries"
cp $SYSDLLPATH/libstdc++* $INSTALLERDATA
cp $SYSDLLPATH/libgcc* $INSTALLERDATA

# Create the installer
echo "Create installer using binarycreator of installer framework - Please wait a minute"
cd $BUILDPATH/installer
$FRAMEWORK/binarycreator --offline-only -c config/config.xml -p packages $BUILDPATH/JustIntonation-openSuse-Installer

# use tasklist -m for detecting loaded dlls

# SFTP access
# If you get: Unable to negotiate with 217.160.221.118: no matching host key type found. Their offer: ssh-dss
# then reenable the old one (not recommended):
# ssh -oHostKeyAlgorithms=+ssh-dss  u81468700-justint@u81468700.1and1-data.host

echo
echo rsync installer to server:
echo rsync -avuz $BUILDPATH/JustIntonation-openSuse-Installer $TARGETURL/JustIntonation-openSuse-Installer
echo
rsync -avuz -e "ssh" $BUILDPATH/JustIntonation-openSuse-Installer $TARGETURL/JustIntonation-openSuse-Installer
echo
echo "DONE"
echo

